simplerr
========

A lightweight WGSI application aiming to remove as much boilerplate code as possible while still keeping abstraction low and functionality high. Based on the fantastic Werkzeug project.


QuickStart
----------

Follow the quickstart tutorial [here](https://github.com/yevrah/simplerr/blob/master/examples/quickstart/README.md).
